==> material-ui-shell-1.2.0.tgz: package/es/containers/SelectableMenuList/SelectableMenuList.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import PropTypes from 'prop-types';
import React, { useState, useEffect } from 'react';
import { useTheme as useAppTheme } from 'material-ui-shell/lib/providers/Theme';
import { useMenu } from 'material-ui-shell/lib/providers/Menu';
import { KeyboardArrowLeft as KeyboardArrowLeftIcon, KeyboardArrowRight, ArrowBack } from '@material-ui/icons';
import { Divider, IconButton, List, ListItem, ListItemIcon, ListItemSecondaryAction, ListItemText, Tooltip, Typography } from '@material-ui/core';

var SelectableMenuList = function SelectableMenuList(_ref) {
  var onIndexChange = _ref.onIndexChange,
      useMinified = _ref.useMinified,
      items = _ref.items,
      index = _ref.index;

  var _useState = useState({}),
      state = _useState[0],
      setState = _useState[1]; //Clears nested state if the root items change
  //Used to open auth menu if we are in a nested menu
  //We use just the length because the auth menu has always less items


  useEffect(function () {
    setState({});
  }, [items.length]);

  var handleNestedItemsClick = function handleNestedItemsClick(item) {
    if (item.nestedItems) {
      var previousItems = state.previousItems || [];
      var previousTitles = state.previousTitles || [];
      var _items = item.nestedItems;
      var title = item.primaryText;
      previousItems.unshift(state.items || _items);
      previousTitles.unshift(state.title || title);
      setState(_extends(_extends({}, state), {}, {
        items: _items,
        previousItems,
        previousTitles,
        title,
        index: item.value
      }));
    } else {
      if (item.value || item.onClick) {
        setState(_extends(_extends({}, state), {}, {
          index: item.value
        }));
      }
    }
  };

  var handleBackClick = function handleBackClick() {
    var previousItems = state.previousItems || [];
    var previousTitles = state.previousTitles || [];
    var items = previousItems[0] || undefined;
    var title = previousTitles[0] || undefined;
    previousItems.shift();
    previousTitles.shift();
    setState(_extends(_extends({}, state), {}, {
      items,
      previousItems,
      previousTitles,
      title
    }));
  };

  var getItem = function getItem(item, i) {
    var _useAppTheme = useAppTheme(),
        isRTL = _useAppTheme.isRTL;

    var _useMenu = useMenu(),
        isMiniMode = _useMenu.isMiniMode;

    var index = state.index;
    delete item.visible;

    if (item !== undefined) {
      if (item.subheader !== undefined) {
        return /*#__PURE__*/React.createElement("div", {
          key: i,
          inset: item.inset,
          style: item.style
        }, item.subheader);
      } else if (item.divider !== undefined) {
        return /*#__PURE__*/React.createElement(Divider, {
          key: i,
          inset: item.inset,
          style: item.style
        });
      } else {
        return /*#__PURE__*/React.createElement(Tooltip, {
          disableFocusListener: true,
          disableTouchListener: true,
          disableHoverListener: !isMiniMode,
          "aria-label": item.primaryText,
          placement: isRTL ? 'left' : 'right',
          title: /*#__PURE__*/React.createElement(Typography, {
            variant: "button",
            children: item.primaryText
          })
        }, /*#__PURE__*/React.createElement(ListItem, {
          button: true,
          selected: index && index === item.value,
          key: i,
          onClick: function onClick(e) {
            onIndexChange(e, item.value);
            handleNestedItemsClick(item);

            if (item.onClick) {
              item.onClick();
            }
          },
          onMouseDown: function onMouseDown(e) {
            if (e.button === 1) {
              var win = window.open("" + item.value, '_blank');
              win.focus();
            }
          }
        }, item.leftIcon && /*#__PURE__*/React.createElement(ListItemIcon, null, item.leftIcon), !useMinified && /*#__PURE__*/React.createElement(ListItemText, {
          primary: item.primaryText
        }), item.nestedItems && !useMinified && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
          onClick: function onClick() {
            handleNestedItemsClick(item);
          }
        }, /*#__PURE__*/React.createElement(IconButton, {
          style: {
            marginRight: useMinified ? 150 : undefined
          }
        }, isRTL ? /*#__PURE__*/React.createElement(KeyboardArrowLeftIcon, null) : /*#__PURE__*/React.createElement(KeyboardArrowRight, {
          color: 'action'
        })))));
      }
    }

    return null;
  };

  var list = state.previousItems && state.previousItems.length > 0 ? state.items : items;
  return /*#__PURE__*/React.createElement(List, {
    value: index,
    onChange: onIndexChange
  }, state.items && state.previousItems && state.previousItems.length > 0 && /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(ListItem, {
    button: true,
    onClick: function onClick() {
      handleBackClick();
    }
  }, /*#__PURE__*/React.createElement(ListItemIcon, null, /*#__PURE__*/React.createElement(ArrowBack, null)), /*#__PURE__*/React.createElement(ListItemText, {
    primary: state.title
  })), /*#__PURE__*/React.createElement(Divider, null)), list.filter(function (item) {
    return item.visible !== false;
  }).map(function (item, i) {
    return getItem(item, i);
  }));
};

SelectableMenuList.propTypes = process.env.NODE_ENV !== "production" ? {
  items: PropTypes.array.isRequired,
  onIndexChange: PropTypes.func.isRequired,
  index: PropTypes.string.isRequired
} : {};
export default SelectableMenuList;

==> material-ui-shell-1.3.3.tgz: package/es/containers/SelectableMenuList/SelectableMenuList.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import PropTypes from 'prop-types';
import React, { useState, useEffect, useCallback } from 'react';
import { useTheme as useAppTheme } from 'material-ui-shell/lib/providers/Theme';
import { useMenu } from 'material-ui-shell/lib/providers/Menu';
import { KeyboardArrowLeft as KeyboardArrowLeftIcon, KeyboardArrowRight, ArrowBack } from '@material-ui/icons';
import { Divider, IconButton, List, ListItem, ListItemIcon, ListItemSecondaryAction, ListItemText, Tooltip, Typography } from '@material-ui/core';
import { useLocation } from 'react-router-dom';

var SelectableMenuList = function SelectableMenuList(_ref) {
  var onIndexChange = _ref.onIndexChange,
      useMinified = _ref.useMinified,
      items = _ref.items,
      index = _ref.index;

  var _useState = useState({}),
      state = _useState[0],
      setState = _useState[1];

  var _useAppTheme = useAppTheme(),
      isRTL = _useAppTheme.isRTL;

  var _useMenu = useMenu(),
      isMiniMode = _useMenu.isMiniMode;

  var _useLocation = useLocation(),
      _useLocation$pathname = _useLocation.pathname,
      pathname = _useLocation$pathname === void 0 ? '' : _useLocation$pathname;

  var loopItems = useCallback(function (items, previousItems, title) {
    if (previousItems === void 0) {
      previousItems = [];
    }

    items.map(function (i) {
      var _i$value = i.value,
          value = _i$value === void 0 ? 'none' : _i$value,
          _i$nestedItems = i.nestedItems,
          nestedItems = _i$nestedItems === void 0 ? [] : _i$nestedItems,
          _i$primaryText = i.primaryText,
          primaryText = _i$primaryText === void 0 ? '' : _i$primaryText;

      if (pathname === value) {
        if (previousItems.length) {
          setState({
            index: value,
            previousItems: [previousItems],
            items,
            title
          });
        } else {
          setState({
            index: value
          });
        }

        return i;
      }

      if (nestedItems.length) {
        loopItems(nestedItems, [].concat(previousItems, [items]), primaryText);
      } //console.log('i', i)


      return i;
    }); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  var list = state.previousItems && state.previousItems.length > 0 ? state.items : items;
  useEffect(function () {
    loopItems(items); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []); //Clears nested state if the root items change
  //Used to open auth menu if we are in a nested menu
  //We use just the length because the auth menu has always less items

  useEffect(function () {//setState({})
  }, [items.length]);

  var handleNestedItemsClick = function handleNestedItemsClick(item) {
    if (item.nestedItems) {
      var previousItems = state.previousItems || [];
      var previousTitles = state.previousTitles || [];
      var _items = item.nestedItems;
      var title = item.primaryText;
      previousItems.unshift(state.items || _items);
      previousTitles.unshift(state.title || title);
      setState(_extends(_extends({}, state), {}, {
        items: _items,
        previousItems,
        previousTitles,
        title,
        index: item.value
      }));
    } else {
      if (item.value || item.onClick) {
        setState(_extends(_extends({}, state), {}, {
          index: item.value
        }));
      }
    }
  };

  var handleBackClick = function handleBackClick() {
    var previousItems = state.previousItems || [];
    var previousTitles = state.previousTitles || [];
    var items = previousItems[0] || undefined;
    var title = previousTitles[0] || undefined;
    previousItems.shift();
    previousTitles.shift();
    setState(_extends(_extends({}, state), {}, {
      items,
      previousItems,
      previousTitles,
      title
    }));
  };

  var getItem = function getItem(item, i) {
    var index = state.index;
    delete item.visible;

    if (item !== undefined) {
      if (item.subheader !== undefined) {
        return /*#__PURE__*/React.createElement("div", {
          key: i,
          inset: item.inset,
          style: item.style
        }, item.subheader);
      } else if (item.divider !== undefined) {
        return /*#__PURE__*/React.createElement(Divider, {
          key: i,
          inset: item.inset,
          style: item.style
        });
      } else {
        return /*#__PURE__*/React.createElement(Tooltip, {
          disableFocusListener: true,
          disableTouchListener: true,
          disableHoverListener: !isMiniMode,
          "aria-label": item.primaryText,
          placement: isRTL ? 'left' : 'right',
          title: /*#__PURE__*/React.createElement(Typography, {
            variant: "button",
            children: item.primaryText
          }),
          key: i
        }, /*#__PURE__*/React.createElement(ListItem, {
          button: true,
          selected: index && index === item.value,
          key: i,
          onClick: function onClick(e) {
            onIndexChange(e, item.value);
            handleNestedItemsClick(item);

            if (item.onClick) {
              item.onClick();
            }
          },
          onMouseDown: function onMouseDown(e) {
            if (e.button === 1) {
              var win = window.open("" + item.value, '_blank');
              win.focus();
            }
          }
        }, item.leftIcon && /*#__PURE__*/React.createElement(ListItemIcon, null, item.leftIcon), !useMinified && /*#__PURE__*/React.createElement(ListItemText, {
          primary: item.primaryText
        }), item.nestedItems && !useMinified && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
          onClick: function onClick() {
            handleNestedItemsClick(item);
          }
        }, /*#__PURE__*/React.createElement(IconButton, {
          style: {
            marginRight: useMinified ? 150 : undefined
          }
        }, isRTL ? /*#__PURE__*/React.createElement(KeyboardArrowLeftIcon, null) : /*#__PURE__*/React.createElement(KeyboardArrowRight, {
          color: 'action'
        })))));
      }
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(List, {
    value: index,
    onChange: onIndexChange
  }, state.items && state.previousItems && state.previousItems.length > 0 && /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(ListItem, {
    button: true,
    onClick: function onClick() {
      handleBackClick();
    }
  }, /*#__PURE__*/React.createElement(ListItemIcon, null, /*#__PURE__*/React.createElement(ArrowBack, null)), /*#__PURE__*/React.createElement(ListItemText, {
    primary: state.title
  })), /*#__PURE__*/React.createElement(Divider, null)), list.length && list.filter(function (item) {
    return item.visible !== false;
  }).map(function (item, i) {
    return getItem(item, i);
  }));
};

SelectableMenuList.propTypes = process.env.NODE_ENV !== "production" ? {
  items: PropTypes.array.isRequired,
  onIndexChange: PropTypes.func.isRequired,
  index: PropTypes.string.isRequired
} : {};
export default SelectableMenuList;
